(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     33873,        834]
NotebookOptionsPosition[     34300,        825]
NotebookOutlinePosition[     34765,        845]
CellTagsIndexPosition[     34722,        842]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Vector Addition of Forces\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2018-10-05",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "Experimental evidence has shown that a force is a vector quantity since it \
has a specified magnitude, direction, and sense and it adds according to the \
parallelogram law. Two common problems in statics involve either finding the \
resultant force, knowing its components, or resolving a known force into two \
components. We will now describe how each of these problems is solved using \
the parallelogram law.\nGiven two forces, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "2"], TraditionalForm]]],
 ", we know their magnitudes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "1"], ",", 
    SubscriptBox["F", "2"]}], TraditionalForm]]],
 " and directions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Theta]", "1"], ",", 
    SubscriptBox["\[Theta]", "2"]}], TraditionalForm]]],
 ". The two forces ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "2"], TraditionalForm]]],
 " can be added together to form the resultant force ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["F", "\[RightVector]"], "R"], "=", " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["F", "\[RightVector]"], "1"], "+", " ", 
     SubscriptBox[
      OverscriptBox["F", "\[RightVector]"], "2"]}]}], TraditionalForm]]],
 ". The adding process is shown below. \nFrom this construction, we can apply \
the law of cosines or the law of sines to the triangle in order to obtain the \
magnitude of the resultant force and its direction. We know that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", 
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "-", 
      SubscriptBox["\[Theta]", "2"]}], "\[RightBracketingBar]"}], "=", 
    RowBox[{
     RowBox[{"\[Alpha]", "+", "\[Beta]"}], "=", " ", 
     RowBox[{"\[Pi]", "-", "\[Gamma]"}]}]}], TraditionalForm]]],
 ", thus we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Gamma]", "=", 
    RowBox[{"\[Pi]", "-", 
     RowBox[{
      RowBox[{"\[LeftBracketingBar]", 
       RowBox[{
        SubscriptBox["\[Theta]", "1"], "-", 
        SubscriptBox["\[Theta]", "2"]}], "\[RightBracketingBar]"}], "."}]}]}],
    TraditionalForm]]],
 " Using law of cosines we know the magnitude of resultant force will be \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "R"], "=", " ", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SubsuperscriptBox["F", "1", "2"], "+", 
       SubsuperscriptBox["F", "2", "2"], "-", 
       RowBox[{"2", 
        SubscriptBox["F", "1"], 
        SubscriptBox["F", "2"], "cos\[Gamma]"}]}]], "=", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["F", "1", "2"], "+", 
        SubsuperscriptBox["F", "2", "2"], "-", 
        RowBox[{"2", 
         SubscriptBox["F", "1"], 
         SubscriptBox["F", "2"], 
         RowBox[{"cos", "(", 
          RowBox[{"\[Pi]", "-", 
           RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
             SubscriptBox["\[Theta]", "1"], "-", 
             SubscriptBox["\[Theta]", "2"]}], "\[RightBracketingBar]"}]}], 
          ")"}]}]}]], "=", 
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["F", "1", "2"], "+", 
        SubsuperscriptBox["F", "2", "2"], "+", 
        RowBox[{"2", 
         SubscriptBox["F", "1"], 
         SubscriptBox["F", "2"], 
         RowBox[{"cos", "(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "2"]}], ")"}]}]}]]}]}]}], 
   TraditionalForm]]],
 "\n\nThus, we get the magnitude ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "R"], TraditionalForm]]],
 ". While for direction, we first get the angles ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", ",", "\[Beta]"}], TraditionalForm]]],
 " by the law of sines, \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox[
      FractionBox[
       SubscriptBox["F", "1"], "sin\[Alpha]"],
      FontSize->20], 
     StyleBox["=",
      FontSize->20], 
     RowBox[{
      StyleBox[
       FractionBox[
        SubscriptBox["F", "2"], "sin\[Beta]"],
       FontSize->20], 
      StyleBox["=",
       FontSize->20], 
      RowBox[{
       RowBox[{
        StyleBox[
         FractionBox[
          SubscriptBox["F", "R"], "sin\[Gamma]"],
         FontSize->20], "\[DoubleRightArrow]", "\[Alpha]"}], 
       StyleBox["=",
        FontSize->20], 
       RowBox[{
        SuperscriptBox["sin", 
         RowBox[{"-", "1"}]], "(", 
        RowBox[{
         StyleBox[
          FractionBox[
           SubscriptBox["F", "1"], 
           SubscriptBox["F", "R"]],
          FontSize->20], "\[CenterDot]", "sin\[Gamma]"}], ")"}]}]}]}], ",", 
    " ", 
    RowBox[{"\[Beta]", 
     StyleBox["=",
      FontSize->20], 
     RowBox[{
      SuperscriptBox["sin", 
       RowBox[{"-", "1"}]], "(", 
      RowBox[{
       StyleBox[
        FractionBox[
         SubscriptBox["F", "2"], 
         SubscriptBox["F", "R"]],
        FontSize->20], "\[CenterDot]", "sin\[Gamma]"}], ")"}]}]}], 
   TraditionalForm]]],
 " \n\nOnce we get ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", ",", "\[Beta]"}], TraditionalForm]]],
 ", we can get the magnitude direction ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]]],
 " by the geometry, \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "=", 
    TagBox[GridBox[{
       {"\[Piecewise]", GridBox[{
          {
           RowBox[{
            SubscriptBox["\[Theta]", "1"], "+", "\[Beta]"}], 
           RowBox[{
            RowBox[{"if", " ", 
             SubscriptBox["\[Theta]", "1"]}], "<", 
            SubscriptBox["\[Theta]", "2"]}]},
          {
           RowBox[{
            SubscriptBox["\[Theta]", "2"], "+", "\[Alpha]"}], 
           RowBox[{
            RowBox[{"if", " ", 
             SubscriptBox["\[Theta]", "1"]}], ">", 
            SubscriptBox["\[Theta]", "2"]}]}
         },
         AllowedDimensions->{2, Automatic},
         Editable->True,
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{1.}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.84]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}},
         Selectable->True]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.35]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     "Piecewise",
     DeleteWithContents->True,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], TraditionalForm]]],
 "\n\nThus we know the magnitude as well as direction of the resultant force ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "\[RightVector]"], "R"], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`f1$$ = 1.5, $CellContext`f2$$ = 
    1., $CellContext`opa1$$ = 1, $CellContext`opa2$$ = 
    1, $CellContext`resultant$$ = 0, $CellContext`showres$$ = 
    1, $CellContext`size$$ = 2, $CellContext`time1$$ = 
    0, $CellContext`time2$$ = 0, $CellContext`time3$$ = 
    0, $CellContext`\[Theta]d1$$ = 30, $CellContext`\[Theta]d2$$ = 120, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`size$$], 2, "Plot Range    "}, {1, 2, 4, 8}}, {{
       Hold[$CellContext`opa1$$], 1, 
       Row[{
        "\!\(\*SubscriptBox[\n StyleBox[\"F\",\nFontSlant->\"Italic\"], \
\"1\"]\) Visibility", 
         Spacer[12]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa2$$], 1, 
       Row[{
        "\!\(\*SubscriptBox[\n StyleBox[\"F\",\nFontSlant->\"Italic\"], \
\"2\"]\) Visibility", 
         Spacer[12]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`f1$$], 1.5, 
       Row[{
        "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"1\"],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \
\",\nFontSlant->\"Italic\"]\)(N)"}]}, 0, 5}, {{
       Hold[$CellContext`\[Theta]d1$$], 30, 
       Row[{
        "\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)(\[Degree])", 
         Spacer[2.5]}]}, 0, 360}, {{
       Hold[$CellContext`f2$$], 1., 
       Row[{
        "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"2\"],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \
\",\nFontSlant->\"Italic\"]\)(N)"}]}, 0, 5}, {{
       Hold[$CellContext`\[Theta]d2$$], 120, 
       Row[{
        "\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\)\!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\)(\[Degree])", 
         Spacer[2.5]}]}, 0, 360}, {{
       Hold[$CellContext`resultant$$], 0, 
       Row[{"Resultant", 
         Spacer[22.5]}]}, {1 -> Text["On"], 0 -> Text["Off"]}}, {{
       Hold[$CellContext`showres$$], 1, ""}, {1 -> Text[
         Style["Parallolegram", 12]], 2 -> Text[
         Style["Head-to-Tail", 12]]}}, {{
       Hold[$CellContext`time3$$], 0, "animation"}, 0, 3}, {{
       Hold[$CellContext`time1$$], 0, 
       "Move \!\(\*SubscriptBox[\n StyleBox[\"F\",\nFontSlant->\"Italic\"], \
\"1\"]\)  "}, 0, 3}, {{
       Hold[$CellContext`time2$$], 0, 
       "Move \!\(\*SubscriptBox[\n StyleBox[\"F\",\nFontSlant->\"Italic\"], \
\"2\"]\)  "}, 0, 3}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          Manipulate`Place[5]}, {
          Manipulate`Place[6]}, {
          Manipulate`Place[7]}, {
          Manipulate`Place[8]}, {
          PaneSelector[{1 -> Manipulate`Place[9]}, 
           Dynamic[$CellContext`resultant$$]]}, {
          PaneSelector[{11 -> Grid[{{
                Manipulate`Place[10]}}], 21 -> Grid[{{
                Manipulate`Place[11]}, {
                Manipulate`Place[12]}}]}, 
           Dynamic[10 $CellContext`showres$$ + $CellContext`resultant$$]]}}, 
        Alignment -> Left, Spacings -> {Automatic, 1.5}]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    600., {296., 304.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`size$68194$$ = 
    0, $CellContext`opa1$68195$$ = False, $CellContext`opa2$68196$$ = 
    False, $CellContext`f1$68197$$ = 0, $CellContext`\[Theta]d1$68198$$ = 
    0, $CellContext`f2$68199$$ = 0, $CellContext`\[Theta]d2$68200$$ = 
    0, $CellContext`resultant$68201$$ = False, $CellContext`showres$68202$$ = 
    False, $CellContext`time3$68203$$ = 0, $CellContext`time1$68204$$ = 
    0, $CellContext`time2$68205$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`f1$$ = 1.5, $CellContext`f2$$ = 
        1., $CellContext`opa1$$ = 1, $CellContext`opa2$$ = 
        1, $CellContext`resultant$$ = 0, $CellContext`showres$$ = 
        1, $CellContext`size$$ = 2, $CellContext`time1$$ = 
        0, $CellContext`time2$$ = 0, $CellContext`time3$$ = 
        0, $CellContext`\[Theta]d1$$ = 30, $CellContext`\[Theta]d2$$ = 120}, 
      "ControllerVariables" :> {
        Hold[$CellContext`size$$, $CellContext`size$68194$$, 0], 
        Hold[$CellContext`opa1$$, $CellContext`opa1$68195$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$68196$$, False], 
        Hold[$CellContext`f1$$, $CellContext`f1$68197$$, 0], 
        Hold[$CellContext`\[Theta]d1$$, $CellContext`\[Theta]d1$68198$$, 0], 
        Hold[$CellContext`f2$$, $CellContext`f2$68199$$, 0], 
        Hold[$CellContext`\[Theta]d2$$, $CellContext`\[Theta]d2$68200$$, 0], 
        Hold[$CellContext`resultant$$, $CellContext`resultant$68201$$, False], 
        Hold[$CellContext`showres$$, $CellContext`showres$68202$$, False], 
        Hold[$CellContext`time3$$, $CellContext`time3$68203$$, 0], 
        Hold[$CellContext`time1$$, $CellContext`time1$68204$$, 0], 
        Hold[$CellContext`time2$$, $CellContext`time2$68205$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`res$, $CellContext`an$, $CellContext`mag$, \
$CellContext`ans$, $CellContext`f1ps$, $CellContext`f2ps$, \
$CellContext`mags$, $CellContext`\[Theta]1$, $CellContext`\[Theta]2$, \
$CellContext`opa3$, $CellContext`opa4$, $CellContext`dw1$, $CellContext`dw2$, \
$CellContext`dw3$, $CellContext`dw4$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`label$, $CellContext`v$, $CellContext`v1$, \
$CellContext`v2$, $CellContext`v3$, $CellContext`t0$ = 
         3}, $CellContext`\[Theta]1$ = ($CellContext`\[Theta]d1$$/180) 
          Pi; $CellContext`\[Theta]2$ = ($CellContext`\[Theta]d2$$/180) 
          Pi; $CellContext`res$ = 
         Dot[{$CellContext`f1$$, $CellContext`f2$$}, {{
             Cos[$CellContext`\[Theta]1$], 
             Sin[$CellContext`\[Theta]1$]}, {
             Cos[$CellContext`\[Theta]2$], 
             
             Sin[$CellContext`\[Theta]2$]}}]; $CellContext`f1ps$ = \
$CellContext`f1$$ {
            Cos[$CellContext`\[Theta]1$], 
            
            Sin[$CellContext`\[Theta]1$]}; $CellContext`f2ps$ = \
$CellContext`f2$$ {
            Cos[$CellContext`\[Theta]2$], 
            Sin[$CellContext`\[Theta]2$]}; $CellContext`mag$ = N[
           Norm[$CellContext`res$]]; $CellContext`an$ = 
         If[$CellContext`res$ != {0, 0}, 
           N[
            Apply[ArcTan, $CellContext`res$]], 0]; $CellContext`v$ = 
         1; $CellContext`v1$ = 
         Norm[$CellContext`f2ps$]/$CellContext`t0$; $CellContext`v2$ = 
         Norm[$CellContext`f1ps$]/$CellContext`t0$; $CellContext`v3$ = 
         Norm[$CellContext`res$]/$CellContext`t0$; $CellContext`dwf1$ = {
           Dashing[{}], 
           Thickness[0.003], 
           Arrowheads[0.03], 
           Arrow[{{-$CellContext`size$$, 0}, {$CellContext`size$$, 0}}], 
           Arrow[{{0, -$CellContext`size$$}, {0, $CellContext`size$$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.9 $CellContext`size$$, (-0.05) $CellContext`size$$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$$, 
             0.9 $CellContext`size$$}]}; $CellContext`dwf2$ = {
           Opacity[
            Boole[
             And[$CellContext`opa1$$ == 1, $CellContext`resultant$$ == 0]]], 
           Thickness[0.005], 
           Arrow[{{0, 0}, $CellContext`f1ps$}], 
           Text[
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "1"], 10], 
            0.5 $CellContext`f1ps$ + 0.12 {
               Cos[$CellContext`\[Theta]1$ + Pi/2], 
               Sin[$CellContext`\[Theta]1$ + Pi/2]}], 
           
           Circle[{0, 0}, 0.25 $CellContext`f1$$, {
            0, $CellContext`\[Theta]1$}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\)", {(
              0.35 $CellContext`f1$$) 
             Cos[$CellContext`\[Theta]1$/2], (0.35 $CellContext`f1$$) 
             Sin[$CellContext`\[Theta]1$/2]}]}; $CellContext`dwf3$ = {
           Opacity[
            Boole[
             And[$CellContext`opa2$$ == 1, $CellContext`resultant$$ == 0]]], 
           Dashing[{}], Blue, 
           Thickness[0.005], 
           Arrow[{{0, 0}, $CellContext`f2ps$}], 
           Text[
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "2"], 10], 
            0.5 $CellContext`f2ps$ + 0.12 {
               Cos[$CellContext`\[Theta]2$ + Pi/2], 
               Sin[$CellContext`\[Theta]2$ + Pi/2]}], 
           
           Circle[{0, 0}, 0.4 $CellContext`f2$$, {
            0, $CellContext`\[Theta]2$}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\)", {(
              0.5 $CellContext`f2$$) 
             Cos[$CellContext`\[Theta]2$/2], (0.5 $CellContext`f2$$) 
             Sin[$CellContext`\[Theta]2$/2]}]}; $CellContext`dwf4$ = {
           Opacity[
            Boole[
             
             And[$CellContext`opa1$$ == 1, $CellContext`resultant$$ == 
              1, $CellContext`showres$$ == 1]]], 
           Thickness[0.005], 
           Arrow[{{0, 0}, $CellContext`f1ps$}], 
           Text[
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "1"], 10], 
            0.5 $CellContext`f1ps$ + 0.12 {
               Cos[$CellContext`\[Theta]1$ + Pi/2], 
               Sin[$CellContext`\[Theta]1$ + Pi/2]}], 
           
           Circle[{0, 0}, 0.25 $CellContext`f1$$, {
            0, $CellContext`\[Theta]1$}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\)", {(
              0.35 $CellContext`f1$$) 
             Cos[$CellContext`\[Theta]1$/2], (0.35 $CellContext`f1$$) 
             Sin[$CellContext`\[Theta]1$/2]}], 
           Opacity[
            Boole[
             
             And[$CellContext`opa2$$ == 1, $CellContext`resultant$$ == 
              1, $CellContext`showres$$ == 1]]], 
           Dashing[{}], Blue, 
           Thickness[0.005], 
           Arrow[{{0, 0}, $CellContext`f2ps$}], 
           Text[
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "2"], 10], 
            0.5 $CellContext`f2ps$ + 0.12 {
               Cos[$CellContext`\[Theta]2$ + Pi/2], 
               Sin[$CellContext`\[Theta]2$ + Pi/2]}], 
           
           Circle[{0, 0}, 0.4 $CellContext`f2$$, {
            0, $CellContext`\[Theta]2$}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\)", {(
              0.5 $CellContext`f2$$) 
             Cos[$CellContext`\[Theta]2$/2], (0.5 $CellContext`f2$$) 
             Sin[$CellContext`\[Theta]2$/2]}]}; $CellContext`dwf5$ = {
           Opacity[
            Boole[
             
             And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
              1, $CellContext`time3$$ == 0]]], 
           Thickness[0.005], Red, 
           Arrow[{{0, 0}, $CellContext`res$}]}; $CellContext`dwf6$ = {
           Opacity[
            Boole[
             
             And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
              1, $CellContext`time3$$ == 0]]], 
           Thickness[0.005], 
           Dashing[Medium], Blue, 
           Line[{$CellContext`f1ps$, $CellContext`res$}]}; $CellContext`dwf7$ = {
           Opacity[
            Boole[
             
             And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
              1, $CellContext`time3$$ == 0]]], 
           Thickness[0.005], 
           Dashing[Medium], Black, 
           Line[{$CellContext`f2ps$, $CellContext`res$}]}; $CellContext`dw2$ = 
         Graphics[{
            Opacity[
             Boole[
              
              And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
               1, $CellContext`time3$$ > 0]]], 
            Thickness[0.005], 
            Dashing[Medium], Blue, 
            ReplaceAll[
             
             Line[{$CellContext`f1ps$, $CellContext`f1ps$ + ($CellContext`v1$ \
$CellContext`t) 
                Normalize[$CellContext`f2ps$]}], {$CellContext`t -> \
$CellContext`time3$$}], Black, 
            ReplaceAll[
             
             Line[{$CellContext`f2ps$, $CellContext`f2ps$ + ($CellContext`v2$ \
$CellContext`t) 
                Normalize[$CellContext`f1ps$]}], {$CellContext`t -> \
$CellContext`time3$$}], 
            Dashing[{}], Red, Thick, 
            ReplaceAll[
             
             Arrow[{{0, 0}, ($CellContext`v3$ $CellContext`t) 
               Normalize[$CellContext`res$]}], {$CellContext`t -> \
$CellContext`time3$$}]}]; $CellContext`dwf8$ = {
           Opacity[
            Boole[
             And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 1, 
              
              Or[$CellContext`time3$$ == 
               0, $CellContext`time3$$ == $CellContext`t0$]]]], Red, Thick, 
           Circle[{0, 0}, 0.32 $CellContext`mag$, {0, $CellContext`an$}], 
           Text[
            Style[
            "\[Theta]", 10], {(0.37 $CellContext`mag$) 
             Cos[$CellContext`an$/3], (0.37 $CellContext`mag$) 
             Sin[$CellContext`an$/3]}], Thin, 
           Text[
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "R"], 
             10], {(1.05 $CellContext`mag$) 
             Cos[$CellContext`an$], (1.05 $CellContext`mag$) 
             Sin[$CellContext`an$]}]}; $CellContext`dw3$ = Graphics[{
            Opacity[
             Boole[
              
              And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
               2]]], 
            Thickness[0.005], 
            ReplaceAll[{
              
              Arrow[{(Normalize[$CellContext`f2ps$] $CellContext`v1$) \
$CellContext`t, (
                  Normalize[$CellContext`f2ps$] $CellContext`v1$) \
$CellContext`t + $CellContext`f1ps$}], 
              Text[
               Style[
                Subscript[
                "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "1"], 
                10], 0.5 $CellContext`f1ps$ + 0.12 {
                  Cos[$CellContext`\[Theta]1$ + Pi/2], 
                  
                  Sin[$CellContext`\[Theta]1$ + 
                   Pi/2]} + ($CellContext`v1$ $CellContext`t) 
                Normalize[$CellContext`f2ps$]], 
              
              Circle[($CellContext`v1$ $CellContext`t) 
               Normalize[$CellContext`f2ps$], 0.25 $CellContext`f1$$, {
               0, $CellContext`\[Theta]1$}], 
              Text[
              "\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\)", {(
                  0.35 $CellContext`f1$$) 
                 Cos[$CellContext`\[Theta]1$/2], (0.35 $CellContext`f1$$) 
                 Sin[$CellContext`\[Theta]1$/
                   2]} + ($CellContext`v1$ $CellContext`t) 
                Normalize[$CellContext`f2ps$]]}, {$CellContext`t -> \
$CellContext`time1$$}], 
            Opacity[
             Boole[
              
              And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
               2, $CellContext`time1$$ > 0]]], 
            Dashing[Medium], 
            ReplaceAll[
             
             Line[{($CellContext`v1$ $CellContext`t) 
               Normalize[$CellContext`f2ps$], ($CellContext`v1$ \
$CellContext`t) Normalize[$CellContext`f2ps$] + {
                0.3 $CellContext`f1$$, 
                 0}}], {$CellContext`t -> $CellContext`time1$$}]}]; \
$CellContext`dw4$ = Graphics[{
            Opacity[
             Boole[
              
              And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
               2]]], 
            Thickness[0.005], Blue, 
            ReplaceAll[{
              
              Arrow[{(Normalize[$CellContext`f1ps$] $CellContext`v2$) \
$CellContext`t, (
                  Normalize[$CellContext`f1ps$] $CellContext`v2$) \
$CellContext`t + $CellContext`f2ps$}], 
              Text[
               Style[
                Subscript[
                "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "2"], 
                10], 0.5 $CellContext`f2ps$ + 0.12 {
                  Cos[$CellContext`\[Theta]2$ + Pi/2], 
                  
                  Sin[$CellContext`\[Theta]2$ + 
                   Pi/2]} + ($CellContext`v2$ $CellContext`t) 
                Normalize[$CellContext`f1ps$]], 
              
              Circle[($CellContext`v2$ $CellContext`t) 
               Normalize[$CellContext`f1ps$], 0.4 $CellContext`f2$$, {
               0, $CellContext`\[Theta]2$}], 
              Text[
              "\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\)", {(
                  0.5 $CellContext`f2$$) 
                 Cos[$CellContext`\[Theta]2$/2], (0.5 $CellContext`f2$$) 
                 Sin[$CellContext`\[Theta]2$/
                   2]} + ($CellContext`v2$ $CellContext`t) 
                Normalize[$CellContext`f1ps$]]}, {$CellContext`t -> \
$CellContext`time2$$}], 
            Opacity[
             Boole[
              
              And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 
               2, $CellContext`time2$$ > 0]]], 
            Dashing[Medium], 
            ReplaceAll[
             
             Line[{($CellContext`v2$ $CellContext`t) 
               Normalize[$CellContext`f1ps$], ($CellContext`v2$ \
$CellContext`t) Normalize[$CellContext`f1ps$] + {
                0.45 $CellContext`f2$$, 
                 0}}], {$CellContext`t -> $CellContext`time2$$}]}]; \
$CellContext`dwf9$ = {
           Opacity[
            Boole[
             And[$CellContext`resultant$$ == 1, $CellContext`showres$$ == 2, 
              
              Or[$CellContext`time1$$ == $CellContext`t0$, \
$CellContext`time2$$ == $CellContext`t0$, $CellContext`time1$$ + \
$CellContext`time2$$ == 0]]]], 
           Thickness[0.005], Red, 
           Arrow[{{0, 0}, $CellContext`res$}], 
           Circle[{0, 0}, 0.32 $CellContext`mag$, {0, $CellContext`an$}], 
           Text[
            Style[
            "\[Theta]", 10], {(0.37 $CellContext`mag$) 
             Cos[$CellContext`an$/3], (0.37 $CellContext`mag$) 
             Sin[$CellContext`an$/3]}], Thin, Red, 
           Text[
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "R"], 
             10], {(1.05 $CellContext`mag$) 
             Cos[$CellContext`an$], (1.05 $CellContext`mag$) 
             Sin[$CellContext`an$]}]}; 
        If[$CellContext`resultant$$ == 
          1, {$CellContext`ans$ = 
           Row[{"\!\(\*\nStyleBox[SubscriptBox[\"F\", \"R\"],\n\
FontSlant->\"Italic\"]\)", 
              Spacer[5], "=", 
              Spacer[5], 
              NumberForm[
               N[$CellContext`mag$], {3, 2}]}], $CellContext`mags$ = 
           Row[{"\[Theta]", 
              Spacer[5], "=", 
              Spacer[5], 
              NumberForm[
               N[$CellContext`an$ (180/Pi)], {3, 2}], 
              "\[Degree]"}]}, {$CellContext`ans$ = "", $CellContext`mags$ = 
           ""}]; $CellContext`label$ = Text[
           Style[
            Grid[{{
               Spacer[30], $CellContext`ans$, $CellContext`mags$}}, Alignment -> 
             Left], 12]]; $CellContext`dw1$ = 
         Graphics[{$CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf5$, $CellContext`dwf4$, \
$CellContext`dwf6$, $CellContext`dwf8$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$}, PlotRange -> $CellContext`size$$, 
           Frame -> True, PlotLabel -> 
           Pane[$CellContext`label$, Alignment -> Left, ImageSize -> 200], 
           ImageSize -> {400, 400}, ImagePadding -> 20]; 
        Show[$CellContext`dw1$, $CellContext`dw2$, $CellContext`dw3$, \
$CellContext`dw4$]], 
      "Specifications" :> {{{$CellContext`size$$, 2, "Plot Range    "}, {1, 2,
          4, 8}, ImageSize -> Tiny, ControlType -> Setter, ControlPlacement -> 
         1}, {{$CellContext`opa1$$, 1, 
          
          Row[{"\!\(\*SubscriptBox[\n StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"1\"]\) Visibility", 
            Spacer[12]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 2}, {{$CellContext`opa2$$, 1, 
          
          Row[{"\!\(\*SubscriptBox[\n StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"2\"]\) Visibility", 
            Spacer[12]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 3}, {{$CellContext`f1$$, 1.5, 
          
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"1\"],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \
\",\nFontSlant->\"Italic\"]\)(N)"}]}, 0, 5, ImageSize -> Tiny, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`\[Theta]d1$$, 30, 
          
          Row[{"\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\)\!\(\*\nStyleBox[\" \
\",\nFontSlant->\"Italic\"]\)(\[Degree])", 
            Spacer[2.5]}]}, 0, 360, ImageSize -> Tiny, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`f2$$, 1., 
          
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"2\"],\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \
\",\nFontSlant->\"Italic\"]\)(N)"}]}, 0, 5, ImageSize -> Tiny, Appearance -> 
         "Labeled", ControlPlacement -> 6}, {{$CellContext`\[Theta]d2$$, 120, 
          
          Row[{"\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\)\!\(\*\nStyleBox[\" \
\",\nFontSlant->\"Italic\"]\)(\[Degree])", 
            Spacer[2.5]}]}, 0, 360, ImageSize -> Tiny, Appearance -> 
         "Labeled", ControlPlacement -> 7}, {{$CellContext`resultant$$, 0, 
          Row[{"Resultant", 
            Spacer[22.5]}]}, {1 -> Text["On"], 0 -> Text["Off"]}, ControlType -> 
         RadioButton, ControlPlacement -> 
         8}, {{$CellContext`showres$$, 1, ""}, {1 -> Text[
            Style["Parallolegram", 12]], 2 -> Text[
            Style["Head-to-Tail", 12]]}, ControlType -> PopupMenu, 
         ControlPlacement -> 9}, {{$CellContext`time3$$, 0, "animation"}, 0, 
         3, ImageSize -> Tiny, ControlType -> Trigger, 
         AppearanceElements -> {"ResetPlayButton"}, ControlPlacement -> 
         10}, {{$CellContext`time1$$, 0, 
          "Move \!\(\*SubscriptBox[\n StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"1\"]\)  "}, 0, 3, ImageSize -> Tiny, ControlType -> 
         Trigger, AppearanceElements -> {"PlayPauseButton", "ResetButton"}, 
         ControlPlacement -> 
         11}, {{$CellContext`time2$$, 0, 
          "Move \!\(\*SubscriptBox[\n StyleBox[\"F\",\n\
FontSlant->\"Italic\"], \"2\"]\)  "}, 0, 3, ImageSize -> Tiny, ControlType -> 
         Trigger, AppearanceElements -> {"PlayPauseButton", "ResetButton"}, 
         ControlPlacement -> 12}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           Manipulate`Place[5]}, {
           Manipulate`Place[6]}, {
           Manipulate`Place[7]}, {
           Manipulate`Place[8]}, {
           PaneSelector[{1 -> Manipulate`Place[9]}, 
            Dynamic[$CellContext`resultant$$]]}, {
           PaneSelector[{11 -> Grid[{{
                 Manipulate`Place[10]}}], 21 -> Grid[{{
                 Manipulate`Place[11]}, {
                 Manipulate`Place[12]}}]}, 
            Dynamic[10 $CellContext`showres$$ + $CellContext`resultant$$]]}}, 
         Alignment -> Left, Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{930., {341., 350.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 253, 8, 230, "Title"],
Cell[1742, 45, 7778, 239, 696, "Text"],
Cell[9523, 286, 24761, 536, 715, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 2wD4dHiYbwSTjDKcK@AnA4uX *)
